ListStyle class

Constructors

ListStyle({Color backgroundColor = Colors.white, BorderRadius? borderRadius, Border? border, TextStyle contentTextStyle = const TextStyle(decorationThickness: 0, color: Color(0xff495057), fontSize: 14, fontFamily: 'Pretendard', fontWeight: FontWeight.w500, height: 1.43), TextStyle hintTextStyle = const TextStyle(color: Color(0xffADB5BD), fontSize: 14, fontFamily: 'Pretendard', fontWeight: FontWeight.w500, height: 1.43), String hintText = '내용을 입력해주세요', EdgeInsets listPadding = const EdgeInsets.symmetric(vertical: 2.0), EdgeInsets textPadding = const EdgeInsets.symmetric(horizontal: 10.0, vertical: 20.0), double animateBeginScale = 1.0, double animateEndScale = 1.1, Icon deleteIcon = const Icon(Icons.cancel, color: Colors.black, size: 18.0)})
const

Properties

animateBeginScale double
final
animateEndScale double
final
backgroundColor Color
final
border Border?
final
borderRadius BorderRadius?
final
contentTextStyle TextStyle
final
deleteIcon Icon
final
hashCode int
The hash code for this object.
no setterinherited
hintText String
final
hintTextStyle TextStyle
final
listPadding EdgeInsets
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textPadding EdgeInsets
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited