ListController class
Constructors
- ListController()
-
factory
Properties
- canWrite ↔ bool
-
getter/setter pair
-
draggableLists
→ ValueNotifier<
List< ListModel> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
listTextControllers
→ ValueNotifier<
List< TextEditingController> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- saveWriteState ← bool
-
no getter
Methods
-
addList(
) → void -
addListTextControllers(
) → void -
initializeListOrder(
List< ListModel> lists) → void -
initializeListTextControllers(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeList(
int index) → void -
removeTextController(
int index) → void -
reorderList(
{required int oldIndex, required int newIndex}) → void -
reorderListTextController(
{required int oldIndex, required int newIndex}) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited